import { SimpleTestLauncherConfigBuilder } from './test-launcher-config-builder';
import { testLauncher } from "../test-launcher";
export declare namespace simpleTestConfigBuilder {
    interface Properties {
        parent: SimpleTestLauncherConfigBuilder | undefined;
        configuration: Configuration;
    }
    interface Configuration {
        type: string;
        specDirPath: string | undefined;
        nativeConfiguration: object;
        specFileFilters: Array<Function | string | RegExp>;
        features: Features;
    }
    interface Features {
        enableJunitXml: boolean;
        enableHtml: boolean;
    }
}
export declare class SimpleTestConfigBuilder {
    protected properties: simpleTestConfigBuilder.Properties;
    constructor(parent?: SimpleTestLauncherConfigBuilder);
    /**
     * The configuration group name
     */
    readonly _subConfigurationGroupName: string;
    /**
     * Clear the configuration
     */
    clear(): SimpleTestConfigBuilder;
    /**
     * Set the spec directory
     * @param [value] The new value. Set undefined to set put the default value
     */
    specDirPath(value?: string | null): SimpleTestConfigBuilder;
    /**
     * Set the test type
     * @param [value] The new value. Set undefined to set put the default value
     */
    type(value?: string | null): SimpleTestConfigBuilder;
    /**
     * Set the type to unit test
     * @see type
     */
    unitTest(): SimpleTestConfigBuilder;
    /**
     * Set the type to integration test
     * @see type
     */
    integrationTest(): SimpleTestConfigBuilder;
    /**
     * Set the type to system test
     * @see type
     */
    systemTest(): SimpleTestConfigBuilder;
    /**
     * Set the native configuration
     * @param [value] The new value. Set undefined to set put the default value
     */
    nativeConfiguration(value?: object | null): SimpleTestConfigBuilder;
    /**
     * Add a new spec filter
     * @param [value] The filter to add
     */
    withSpecFileFilter(value?: Function | string | RegExp): SimpleTestConfigBuilder;
    /**
     * Returns the parent builder
     */
    parentBuilder(): SimpleTestLauncherConfigBuilder;
    /**
     * Generate the object configuration
     */
    build(): testLauncher.configuration.test.Configuration;
    /**
     * Returns the default configuration
     */
    protected _defaultConfiguration(): simpleTestConfigBuilder.Configuration;
}
