"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
class SimpleTestConfigBuilder {
    constructor(parent) {
        this.properties = {
            parent,
            configuration: this._defaultConfiguration()
        };
    }
    /**
     * The configuration group name
     */
    get _subConfigurationGroupName() {
        return 'test';
    }
    /**
     * Clear the configuration
     */
    clear() {
        this.properties.configuration = this._defaultConfiguration();
        return this;
    }
    /**
     * Set the spec directory
     * @param [value] The new value. Set undefined to set put the default value
     */
    specDirPath(value) {
        if (_.isNil(value)) {
            this.properties.configuration.specDirPath = this._defaultConfiguration().specDirPath;
        }
        else if (_.isString(value)) {
            this.properties.configuration.specDirPath = value;
        }
        return this;
    }
    /**
     * Set the test type
     * @param [value] The new value. Set undefined to set put the default value
     */
    type(value) {
        if (_.isNil(value)) {
            this.properties.configuration.type = this._defaultConfiguration().type;
        }
        else if (_.isString(value)) {
            this.properties.configuration.type = value;
        }
        return this;
    }
    /**
     * Set the type to unit test
     * @see type
     */
    unitTest() {
        return this.type('unit');
    }
    /**
     * Set the type to integration test
     * @see type
     */
    integrationTest() {
        return this.type('integration');
    }
    /**
     * Set the type to system test
     * @see type
     */
    systemTest() {
        return this.type('system');
    }
    /**
     * Set the native configuration
     * @param [value] The new value. Set undefined to set put the default value
     */
    nativeConfiguration(value) {
        if (_.isNil(value)) {
            this.properties.configuration.nativeConfiguration = this._defaultConfiguration().nativeConfiguration;
        }
        else if (_.isObject(value)) {
            this.properties.configuration.nativeConfiguration = value;
        }
        return this;
    }
    /**
     * Add a new spec filter
     * @param [value] The filter to add
     */
    withSpecFileFilter(value) {
        if (_.isFunction(value) || _.isRegExp(value) || _.isString(value)) {
            this.properties.configuration.specFileFilters.push(value);
        }
        return this;
    }
    /**
     * Returns the parent builder
     */
    parentBuilder() {
        return this.properties.parent;
    }
    /**
     * Generate the object configuration
     */
    build() {
        const userConfig = {
            type: this.properties.configuration.type,
            specFileFilters: this.properties.configuration.specFileFilters,
            specDirPath: this.properties.configuration.specDirPath,
            jasmine: {
                features: {
                    enableJunitXml: this.properties.configuration.features.enableJunitXml,
                    enableHtml: this.properties.configuration.features.enableHtml
                },
                nativeConfig: this.properties.configuration.nativeConfiguration
            }
        };
        return userConfig;
    }
    /**
     * Returns the default configuration
     */
    _defaultConfiguration() {
        return {
            type: 'unknown',
            specDirPath: undefined,
            nativeConfiguration: {},
            specFileFilters: [],
            features: {
                enableJunitXml: true,
                enableHtml: true
            }
        };
    }
}
exports.SimpleTestConfigBuilder = SimpleTestConfigBuilder;
//# sourceMappingURL=test-config-builder.js.map