"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("./logger");
const NYC = require("nyc");
const process_template_1 = require("./utils/process-template");
const _ = require("lodash");
class SimpleCoverageRunner {
    constructor() {
        this.properties = {};
        this.logger = logger_1.createLogger('coverage');
    }
    async initialize(options) {
        this.properties.configuration = options;
        this.properties.nativeConfiguration = {
            sourceMap: true,
            extension: ['.ts'],
            // include: [
            //   "src/**/*.js"
            // ],
            exclude: [
                "**/*.spec.js",
                "*.spec.js",
                "**/*.spec.ts",
                "*.spec.ts"
            ],
            reporter: [
                "lcov",
                // "text-summary",
                'json'
            ],
            // require: ['source-map-support/register'],
            cwd: this.properties.configuration.projectDirectoryPath,
            reportDir: this.properties.configuration.reportDirectoryPath,
            produceSourceMap: true,
            hookRequire: true,
            excludeAfterRemap: true,
            cache: true
        };
        this.logger.debug(`Create the nyc instance`);
        this.properties.instance = new NYC(this.properties.nativeConfiguration);
        this.logger.debug(`Remove the wrap exit`);
        // @ts-ignore
        this.properties.instance._wrapExit = () => {
            // Nothing
        };
    }
    start() {
        this.logger.debug(`Create the temporary directory`);
        // @ts-ignore
        this.properties.instance.reset();
        this.logger.debug(`Wrap`);
        // @ts-ignore
        this.properties.instance.wrap();
    }
    async saveReports() {
        this.logger.debug(`Write the coverage file`);
        // @ts-ignore
        this.properties.instance.writeCoverageFile();
        this.logger.debug(`Generate the reports`);
        // @ts-ignore
        this.properties.instance.report();
    }
    async clean() {
        this.logger.debug(`Clean up the instance`);
        // @ts-ignore
        this.properties.instance.cleanup();
    }
    async generateSummary(options) {
        this.logger.debug(`Require the lib report`);
        const libReport = require('istanbul-lib-report');
        this.logger.debug(`Get the map report`);
        // @ts-ignore
        const map = this.properties.instance.getCoverageMapFromAllCoverageFiles();
        this.logger.debug(`Get the summarize from the map`);
        const tree = libReport.summarizers.pkg(map);
        let summary;
        const visitor = {
            // onDetail(node)
            // onSummary(node)
            // onStart(node, context)
            onStart(node) {
                summary = node.getCoverageSummary().data;
            }
        };
        tree.visit(visitor);
        const knownKeys = ['lines', 'statements', 'functions', 'branches'];
        const doSum = property => {
            let total = 0;
            _.each(knownKeys, key => {
                total += summary[key][property];
            });
            return total;
        };
        const templateVariables = {
            total: {
                percent: Number((doSum('pct') / 4).toFixed(2)),
                pct: doSum('pct') / 4,
                total: doSum('total'),
                covered: doSum('covered'),
                skipped: doSum('skipped')
            }
        };
        _.each(knownKeys, key => {
            templateVariables[key] = _.cloneDeep(summary[key]);
            templateVariables[key].percent = templateVariables[key].pct;
        });
        this.logger.debug(`Process the template`);
        const { data: generatedSummary } = await process_template_1.processTemplate({
            template: options.template,
            variables: templateVariables
        });
        this.logger.debug(`Returns the generated summary`);
        return generatedSummary;
    }
}
exports.SimpleCoverageRunner = SimpleCoverageRunner;
//# sourceMappingURL=simple-coverage-runner.js.map