/// <reference types="node" />
import { EventEmitter } from "events";
import { Logger } from "./logger";
import { SimpleJasmineRunner } from "./simple-jasmine-runner";
import { TestLauncher, testLauncher } from './test-launcher';
import { CoverageRunner } from "./coverage-runner";
export declare namespace simpleTestLauncher {
    interface Properties {
        steps: testLauncher.Steps;
        executionContext: object;
        processExitCode: number;
        activatedStates: string[];
        jasmineRunner?: SimpleJasmineRunner;
        coverageRunner?: CoverageRunner;
        configuration?: testLauncher.configuration.Configuration;
    }
    interface ExecuteStepOptions {
        groupName: string;
        context: testLauncher.BaseStepHandlerContext;
        stopOnError?: boolean;
    }
}
export declare class SimpleTestLauncher extends EventEmitter implements TestLauncher {
    /**
     * Execute the test from the given configuration
     * @param config The configuration
     */
    static run(config: testLauncher.configuration.Configuration): Promise<void>;
    /**
     * Execute the test from the given configuration in background and exit when finished.
     * @param config The configuration
     */
    static execute(config: testLauncher.configuration.Configuration): void;
    protected properties: simpleTestLauncher.Properties;
    protected logger: Logger;
    constructor();
    defaultConfiguration(): testLauncher.configuration.Configuration;
    /**
     * Merge multiple configuration to 1
     * @param args Configurations
     */
    mergeConfiguration(...args: testLauncher.configuration.Configuration[]): testLauncher.configuration.Configuration;
    initialize(options: testLauncher.configuration.Configuration): Promise<void>;
    /**
     * Launch the test pipeline
     */
    run(): Promise<void>;
    isReady(): boolean;
    isRunning(): boolean;
    shutDown(): void;
    getTestType(): string;
    getProjectRootDirPath(): string;
    getRootReportPath(): string;
    getRootReportTestPath(): string;
    getTestSpecDirPath(): string;
    isCoverageEnabled(): boolean;
    /**
     * Run the initialization before launching test
     */
    protected runPreTest(): Promise<void>;
    protected runTest(): Promise<void>;
    /**
     * Post test execution
     */
    protected runPostTest(): Promise<void>;
    protected createStepBaseContext(): testLauncher.BaseStepHandlerContext;
    protected executeSteps(options: simpleTestLauncher.ExecuteStepOptions): Promise<void>;
    protected addActiveState(stateName: any): void;
    protected removeActiveState(stateName: any): void;
    /**
     * Save the coverage and may print the summary
     * @param context
     */
    protected _autoStepPostExecutionSaveCoverage(context: testLauncher.PostExecutionStepHandlerContext): Promise<testLauncher.StepHandlerOnResolve>;
}
